@@ -72,11 +72,24 @@ class VkontakteBoardTest(TestCase):
         group = GroupFactory.create(remote_id=GROUP_ID)
         topic = TopicFactory.create(remote_id=TOPIC_ID, group=group)
 
-        comments = topic.fetch_comments(count=20)
+        comments = topic.fetch_comments(count=20, sort='desc')
         self.assertTrue(len(comments) == topic.comments.count() == 20)
 
+        # testing `after` parameter
+        after = Comment.objects.order_by('date')[0].date
+
+        Comment.objects.all().delete()
+        self.assertEqual(Comment.objects.count(), 0)
+
+        comments = topic.fetch_comments(after=after, sort='desc')
+        self.assertTrue(len(comments) == Comment.objects.count() == topic.comments.count() == 20)
+
+        # testing `all` parameter
+        Comment.objects.all().delete()
+        self.assertEqual(Comment.objects.count(), 0)
+
         comments = topic.fetch_comments(all=True)
-        self.assertEqual(len(comments), topic.comments.count())
+        self.assertTrue(len(comments) == Comment.objects.count() == topic.comments.count())
         self.assertTrue(topic.comments.count() > 20)
 
     def test_fetching_comments_of_deleted_topic(self):
